<?php
/**
 * @package Dashboard_Feeds_Dashboard_Widget
 * @version 1.0
 */
/*
Plugin Name: Dashboard Feeds Dashboard Widget
Plugin URI: https://vmahq.com
Description: Display rss feeds on your dashboard
Author: Doug Higson
Version: 1.0
Author URI: https://virtualmarketadvantage.com
 */

/* !1. INCLUDES */

// Advanced Custom Fields Settings

// Define path and URL to the ACF plugin.
define('DFDW_MY_HOTDOG_PATH', get_stylesheet_directory() . '/includes/acf/');
define('DFDW_MY_HOTDOG_URL', get_stylesheet_directory_uri() . '/includes/acf/');

// Include the ACF plugin.
include_once plugin_dir_path(__FILE__) . 'includes/acf/acf.php';

// (Optional) Hide the ACF admin menu item.
add_filter('acf/settings/show_admin', 'dfdw_my_hotdog_settings_show_admin');
function dfdw_my_hotdog_settings_show_admin($show_admin)
{
    return false;
}

// CUSTOM POST TYPES

include_once plugin_dir_path(__FILE__) . 'cpt/dashboard_feeds.php';

// ADMIN PAGES

//add menu

// create custom plugin settings menu
add_action('admin_menu', 'dfdw_create_menu_hotdog');

function dfdw_create_menu_hotdog()
{

    //create new top-level menu
    add_options_page('Dashboard Feeds Widget', 'Dashboard Feeds', 'administrator', 'edit.php?post_type=dashboard_feed');

}

// CUSTOM FUNCTIONS

/* !4. ADMIN PAGES */

//Admin Columns

/*
 * Register columns to Important Dates post list
 */
function dfdw_add_hotdog_columns($columns)
{
    return array_merge($columns, array(
        'feed_name' => __('Feed Name'),
        'feed_url' => __('URL'),

    ));
}
add_filter('manage_dashboard_feed_posts_columns', 'dfdw_add_hotdog_columns');

/*
 * Add column data to Important Dates post list
 */

function dfdw_dashboard_feed_custom_column($column, $post_id)
{
    switch ($column) {
        case 'feed_name':
            echo esc_html(get_post_meta($post_id, 'feed_name', true));
            break;
        case 'feed_url':
            echo esc_url(get_post_meta($post_id, 'feed_url', true));
            break;
    }
}
add_action('manage_dashboard_feed_posts_custom_column', 'dfdw_dashboard_feed_custom_column', 10, 2);

// make edit all sortable

add_filter('manage_dashboard_feed_posts_sortable_columns', 'dfdw_my_sortable_event_column');

function dfdw_my_sortable_event_column($columns)
{
    $columns['feed_name'] = 'feed_name';
    $columns['feed_url'] = 'feed_url';

    return $columns;
}

add_action('pre_get_posts', 'dfdw_manage_wp_posts_be_qe_pre_get_posts_hotdog', 1);
function dfdw_manage_wp_posts_be_qe_pre_get_posts_hotdog($query)
{

    if ($query->is_main_query() && ($orderby = $query->get('orderby'))) {
        switch ($orderby) {
            case 'feed_name':
                $query->set('meta_key', 'feed_name');
                $query->set('orderby', 'meta_value');
                break;

            case 'feed_url':
                $query->set('meta_key', 'feed_url');
                $query->set('orderby', 'meta_value');
                break;
        }
    }
}

//remove admin columns

add_filter('manage_dashboard_feed_posts_columns', function ($columns) {
    unset($columns['title'], $columns['date']);
    return $columns;
});

//remove admin sub menus links

add_filter('post_row_actions', 'dfdw_mycustomtheme_remove_myposttype_row_actions_hotdog');
function dfdw_mycustomtheme_remove_myposttype_row_actions_hotdog($action)
{
    if ('dashboard_feed' == get_post_type()) {
        unset($action['view']);
        unset($action['inline hide-if-no-js']);
    }
    return $action;
}

// remove admin notices

add_filter('post_updated_messages', 'post_published_hotdog_dfdw');

function post_published_hotdog_dfdw($messages)
{
    if ('dashboard_feed' === get_post_type()) {
        unset($messages['posts'][6]);
    } else {
        return $messages;
    }
}

/** START The News Feed Dashboard Widget */

add_action('wp_dashboard_setup', 'dfdw_feed_dashboard_add_widgets_hotdogs');

function dfdw_feed_dashboard_add_widgets_hotdogs()
{

    $args = array('post_type' => 'dashboard_feed',
        'numberposts' => '-1',
    );

    $loop = new WP_Query($args);
    while ($loop->have_posts()): $loop->the_post();
        $feed_id = get_post()->ID;

        $feed_name = get_field('feed_name');

        wp_add_dashboard_widget($feed_name, $feed_name, 'dashboard_feeds_widget_hotdog', null, $feed_id);

    endwhile;

}

function dashboard_feeds_widget_hotdog($post, $callback_args)
{
  $post_id = $callback_args['args'];
  $feed_url = get_field('feed_url', $post_id);
  $feed_name = get_field('feed_name', $post_id);
  $feed_number = get_field('number_wang_feed', $post_id);

  $feed = array(
      array(
          'url' => $feed_url,
          'items' => $feed_number,
          'show_summary' => 1,
          'show_author' => 0,
          'show_date' => 1,

      ),

  );
  ob_start(); // start output buffering
  wp_dashboard_primary_output($feed_name, $feed);
  $buffer = ob_get_clean(); // get the buffer without printing the content

  // add the target attribute to the a-tag:
  $result = str_replace("<a class='rsswidget'",
      "<a class='rsswidget' target='_blank'", $buffer);
  echo esc_html ($result);
}
